#include "GameManager.h"


GameManager& GameManager::getSingleton(){
	static GameManager Game;
	return Game;
}

GameManager::GameManager(){
	initiated = false;
}

//Initsierar skrmen dess storlek, bpp samt namn
bool GameManager::Init(int SCREEN_WIDTH, int SCREEN_HEIGHT, int SCREEN_BPP, std::string gameName){
	initiated = true;
	srand(SDL_GetTicks());

	if(SDL_Init(SDL_INIT_EVERYTHING) == -1)
		return false;

	screen = SDL_SetVideoMode(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE);
	if(screen == NULL)
		return false;

	if(TTF_Init() == -1)
		return false;

	if(Mix_OpenAudio(44100, MIX_DEFAULT_FORMAT, 2, 4096) == -1)
		return false;

	SDL_WM_SetCaption(gameName.c_str(), NULL);
	return true;
}

//Uppdaterar skrmen
bool GameManager::Update(float pdt){
	bool exit = false;
	if(initiated){
		for(unsigned int i = 0; i < gameScreens.size(); i++){  // Preventing from other screens to be overlayed
			if(i != 0){
				if(!gameScreens[i - 1]->blockLowerUpdate)
					gameScreens[i]->Update(pdt);
				exit = true;
			}
			else if(gameScreens[i]->Update(pdt))
				exit = true;
			}
		}
	return exit;
}

//Ritar ut alla objekt p skrmen
void GameManager::Draw(){
	if(initiated){
		for(unsigned int i = 0; i < gameScreens.size(); i++){
			if(gameScreens[i]->visible)
				gameScreens[i]->Draw(screen);
		}
	}
}


//Lgger till nya objekt
void GameManager::addEntity(Entity *entity, std::string name){
	for(unsigned int i = 0; i < gameScreens.size(); i++){
		if(gameScreens[i]->getName() == name){
			entity->Init();
			gameScreens[i]->addEntity(entity);
			break;
		}
	}
}

//Raderar gamla objekt
void GameManager::delEntity(Entity *entity, std::string name){
	for(unsigned int i = 0; i < gameScreens.size(); i++){
		if(gameScreens[i]->getName() == name){
			gameScreens[i]->delEntity(entity);
		}
	}
}

//Lgger till ny spelplan i spelet
void GameManager::addGameScreen(GameScreen *pGameScreen, std::string name){
	gameScreens.push_back(pGameScreen);
	pGameScreen->Init(name);
}

//Returnerar den aktuella spelplanen
GameScreen *GameManager::getGameScreen(std::string name){
	for(unsigned int i = 0; i <gameScreens.size(); i++){
		if(gameScreens[i]->getName() == name){
			return gameScreens[i];
		}
	}
	return NULL;
}

//Tar bort spelplan
void GameManager::delGameScreen(std::string name){
	for(unsigned int i = 0; i < gameScreens.size(); i++){
		if(gameScreens[i]->getName() == name){
			GameScreen *temp = gameScreens.back();
			gameScreens.back() = gameScreens[i];
			gameScreens[i] = temp;
			delete gameScreens.back();
			gameScreens.pop_back();
			break;
		}
	}
}
