#include "Image.h"

Image::Image(){
	img = NULL;
	img = IMG_Load("x.png");
	if(img){
		img = SDL_DisplayFormatAlpha(img);
		img->refcount++;
	}
	else 
		throw std::logic_error("Null pointer in default Image constructor");
}

Image::Image(std::string filename){
	img = NULL;
	img = IMG_Load(filename.c_str());
	if(img){
		img = SDL_DisplayFormatAlpha(img);
		img->refcount++;
	}
	else
		throw std::logic_error("Null pointer in Image constructor");
}

Image::Image(const Image& other){
	img = other.getSurface();
	if(img)
		img->refcount++;
}

Image::~Image(){
	img->refcount--;
	SDL_FreeSurface(img);
}

const Image& Image::operator=(const Image& other){
	if(other.getSurface() != getSurface()){
		if(img && (--img->refcount == 0))
			SDL_FreeSurface(img);
		img = other.getSurface();
		if(img)
			img->refcount++;
	}
	return *this;
}

void Image::draw(Vector2 pos, SDL_Surface* screen){
	SDL_Rect rect;
	rect.x = pos.x;
	rect.y = pos.y;

	SDL_BlitSurface(img, NULL, screen, &rect);
}


void Image::addAnim(int x, int y, int w, int h, int frames){
	clips.clear();
	for(int i = 0; i < frames; i++)
		clips.push_back(new SDL_Rect());
	
	for(unsigned int i = 0; i < clips.size(); i++){
		clips[i]->x = x + (w * i);
		clips[i]->y = y;
		clips[i]->w = w;
		clips[i]->h = h;
	}
}

void Image::drawAnim(Vector2 pos, SDL_Surface* screen, int frame){
	SDL_Rect rect;
	rect.x = pos.x;
	rect.y = pos.y;
	
	if(clips.size() <= 1)
		SDL_BlitSurface(img, clips[0], screen, &rect);
	else{
		for(unsigned int i = 0; i < clips.size(); i++){
			if(i == frame)
				SDL_BlitSurface(img, clips[i], screen, &rect);
		}
	}
}

int Image::w(){
	return img->w;
}

int Image::h(){
	return img->h;
}

SDL_Surface* Image::getSurface() const{
	return img;
}
