#include "MainScreen.h"


MainScreen::MainScreen(){
}

MainScreen::~MainScreen(){
	Mix_FreeMusic(music);
}


void MainScreen::Init(std::string pName){
	name = pName;
	blockLowerUpdate = false;
	quit = false;
	info = false;
	credits = false;

	if(GameManager::getSingleton().getGameScreen("Stage1"))
		GameManager::getSingleton().delGameScreen("Stage1");

	music = Mix_LoadMUS("Sound/Elwood-Memory.mp3");
 	Mix_PlayMusic(music, -1);

	GameManager::getSingleton().file.get("Image/stars1.png");
	GameManager::getSingleton().file.get("Image/stars2.png");
	GameManager::getSingleton().file.get("Image/planet.png");

	GameManager::getSingleton().file.get("Image/Play.png")->addAnim(0, 0, 134, 92, 2);
	GameManager::getSingleton().file.get("Image/Info.png")->addAnim(0, 0, 128, 92, 2);
	GameManager::getSingleton().file.get("Image/ExitButton.png")->addAnim(0, 0, 128, 81, 2);

	rectPlay.x = (SCREEN_WIDTH / 3) - (GameManager::getSingleton().file.get("Image/Play.png")->w() / 4);
	rectPlay.y = SCREEN_HEIGTH - (SCREEN_HEIGTH / 3);
	rectPlay.w = GameManager::getSingleton().file.get("Image/Play.png")->w() / 2;
	rectPlay.h = GameManager::getSingleton().file.get("Image/Play.png")->h();

	rectInfo.x = (SCREEN_WIDTH / 2) - ((GameManager::getSingleton().file.get("Image/Info.png")->w()) / 4);
	rectInfo.y = SCREEN_HEIGTH - (SCREEN_HEIGTH / 3);
	rectInfo.w = GameManager::getSingleton().file.get("Image/Info.png")->w() / 2;
	rectInfo.h = GameManager::getSingleton().file.get("Image/Info.png")->h();

	rectExit.x = SCREEN_WIDTH - (SCREEN_WIDTH / 3) - (GameManager::getSingleton().file.get("Image/ExitButton.png")->w() / 4);
	rectExit.y = SCREEN_HEIGTH - (SCREEN_HEIGTH / 3);
	rectExit.w = GameManager::getSingleton().file.get("Image/ExitButton.png")->w() / 2;
	rectExit.h = GameManager::getSingleton().file.get("Image/ExitButton.png")->h();

	fontBig = TTF_OpenFont("pirulen.ttf", 42);
	fontMed = TTF_OpenFont("pirulen.ttf", 18);
}

bool MainScreen::Update(float pdt){
	for(unsigned int i = 0; i < entities.size(); i++){
		if(entities[i]->Update(pdt))
			return true;

		if(entities[i]->dead){
			GameManager::getSingleton().delEntity(entities[i], name);
			continue;
		}
	}

	if(quit)
		return true;
	return false;
}

void MainScreen::Draw(SDL_Surface* screen){
	for(unsigned int i = 0; i < entities.size(); i++){
		entities[i]->Draw(screen);
	}
	GameManager::getSingleton().file.get("Image/stars1.png")->draw(Vector2(0, 0), screen);
	GameManager::getSingleton().file.get("Image/stars2.png")->draw(Vector2(0, 0), screen);
	GameManager::getSingleton().file.get("Image/planet.png")->draw(Vector2(260, 0), screen);

	if(info)
		showInfo(screen);
	else if(credits)
		showCredits(screen);
	else
		menu(screen);

}

std::string MainScreen::getName(){
	return name;
}

void MainScreen::addEntity(Entity *entity){
	entities.push_back(entity);
}

void MainScreen::delEntity(Entity* entity){
	for(unsigned int i = 0; i < entities.size(); i++) {
		if(entities[i] == entity) {
			Entity* temp = entities.back();
			entities.back() = entities[i];
			entities[i] = temp;
			delete entities.back();
			entities.pop_back();
			break;
		}
	}	
}

void MainScreen::menu(SDL_Surface* screen){
	SDL_Color textColor = {222, 246, 250};
	txt = TTF_RenderText_Solid(fontBig, "STAROIDS", textColor);
	rect.x = (SCREEN_WIDTH / 2) - (txt->w / 2);
	rect.y = SCREEN_HEIGTH / 4;
	SDL_BlitSurface(txt, NULL, screen, &rect);
	SDL_FreeSurface(txt);

	mousePos = GameManager::getSingleton().eve.getMousePos();


	if((mousePos.x > rectPlay.x) && (mousePos.x < rectPlay.x + rectPlay.w) && (mousePos.y > rectPlay.y) && (mousePos.y < rectPlay.y + rectPlay.h)){
		GameManager::getSingleton().file.get("Image/Play.png")->drawAnim(Vector2(rectPlay.x, rectPlay.y), screen, 1);
		if(GameManager::getSingleton().eve.mouseButtonHit(1))
			GameManager::getSingleton().addGameScreen(new LoadingScreen(), "LoadingScreen");
	}
	else
		GameManager::getSingleton().file.get("Image/Play.png")->drawAnim(Vector2(rectPlay.x, rectPlay.y), screen, 0);

	if((mousePos.x > rectInfo.x) && (mousePos.x < rectInfo.x + rectInfo.w) && (mousePos.y > rectInfo.y) && (mousePos.y < rectInfo.y + rectInfo.h)){
		GameManager::getSingleton().file.get("Image/Info.png")->drawAnim(Vector2(rectInfo.x, rectInfo.y), screen, 1);
		if(GameManager::getSingleton().eve.mouseButtonHit(1)){
			info = true;
			timeclick.start();
		}
	}
	else
		GameManager::getSingleton().file.get("Image/Info.png")->drawAnim(Vector2(rectInfo.x, rectPlay.y), screen, 0);
		
	if((mousePos.x > rectExit.x) && (mousePos.x < rectExit.x + rectExit.w) && (mousePos.y > rectExit.y) && (mousePos.y < rectExit.y + rectExit.h)){
		GameManager::getSingleton().file.get("Image/ExitButton.png")->drawAnim(Vector2(rectExit.x, rectExit.y), screen, 1);
		if(GameManager::getSingleton().eve.mouseButtonHit(1)){
			quit = true;
		}
	}
	else
		GameManager::getSingleton().file.get("Image/ExitButton.png")->drawAnim(Vector2(rectExit.x, rectExit.y), screen, 0);
}

void MainScreen::showInfo(SDL_Surface* screen){
	int height = 40;
	int extendedSpace = 0;
	SDL_Color textColor = {222, 246, 250};

	for(int i = 0; i < 9; i++){
		switch(i){
		case 0:
			txt = TTF_RenderText_Solid(fontMed, "Welcome to the game Staroids!", textColor);
			break;
		case 1:
			txt = TTF_RenderText_Solid(fontMed, "Steer your ship up and down with the W and S button.", textColor);
			extendedSpace = 80;
			break;
		case 2:
			txt = TTF_RenderText_Solid(fontMed, "Accelrate and deaccelrate with D and A button", textColor);
			extendedSpace = 0;
			break;
		case 3:
			txt = TTF_RenderText_Solid(fontMed, "Shoot with your Spacebar.", textColor);
			extendedSpace = 40;
			break;
		case 4:
			txt = TTF_RenderText_Solid(fontMed, "Buy repairs for your ship with H button.", textColor);
			break;
		case 5:
			txt = TTF_RenderText_Solid(fontMed, "Buy upgrades for your cannons with B button.", textColor);
			break;
		case 6:
			txt = TTF_RenderText_Solid(fontMed, "Buy more rapid fire for your cannon with N button.", textColor);
			break;
		case 7:
			txt = TTF_RenderText_Solid(fontMed, "Fire missiles with M button, this cost but does great damage.", textColor);
			break;
		case 8:
			txt = TTF_RenderText_Solid(fontMed, "Press left mousebutton to continue.", textColor);
			extendedSpace = 120;
			break;
		}

		rect.x = (SCREEN_WIDTH / 2) - (txt->w / 2);
		rect.y = SCREEN_HEIGTH / 5 + (height * i) + extendedSpace;
		SDL_BlitSurface(txt, NULL, screen, &rect);
		SDL_FreeSurface(txt);

	}

	if((GameManager::getSingleton().eve.mouseButtonHit(1)) && (timeclick.get_ticks() > 250)){
		credits = true;
		info = false;
		timeclick.start();
	}
}

void MainScreen::showCredits(SDL_Surface* screen){
	int height = 40;
	int extendedSpace = 0;
	SDL_Color textColor = {222, 246, 250};

	for(int i = 0; i < 8; i++){
		switch(i){
		case 0:
			txt = TTF_RenderText_Solid(fontMed, "Game programmed by:", textColor);
			break;
		case 1:
			txt = TTF_RenderText_Solid(fontMed, "Samuel Haggren", textColor);	
			break;
		case 2:
			txt = TTF_RenderText_Solid(fontMed, "Music made by:", textColor);
			extendedSpace = 40;
			break;
		case 3:
			txt = TTF_RenderText_Solid(fontMed, "Elwood", textColor);
			break;
		case 4:
			txt = TTF_RenderText_Solid(fontMed, "Graphic made by:", textColor);
			extendedSpace = 80;
			break;
		case 5:
			txt = TTF_RenderText_Solid(fontMed, "Samuel Haggren", textColor);
			break;
		case 6:
			txt = TTF_RenderText_Solid(fontMed, "Hard Vacuum", textColor);
			break;
		case 7:
			txt = TTF_RenderText_Solid(fontMed, "Press left mousebutton to continue.", textColor);
			extendedSpace = 120;
			break;
		}

		rect.x = (SCREEN_WIDTH / 2) - (txt->w / 2);
		rect.y = SCREEN_HEIGTH / 5 + (height * i) + extendedSpace;
		SDL_BlitSurface(txt, NULL, screen, &rect);
		SDL_FreeSurface(txt);

	}
	if((GameManager::getSingleton().eve.mouseButtonHit(1)) && (timeclick.get_ticks() > 250)){
		credits = false;
	}
}