#include "Ship.h"

Ship::Ship(){
	img = "Image/ship.png";
}

Ship::~Ship(){
	Mix_FreeChunk(sfx);	
}

void Ship::Init(){
	Solid::Init();
	pos.x = 100;
	pos.y = 300;
	size = 60;
	speed = 2.5f;
	bulletSpeed = 300;
	huzzelInterval = 200;
	image->addAnim(0, 0, 64, 64, 3);
	time.start();
	timerBullet.start();
	timerRocket.start();
	anim = true;
	win = false;
	
	sfx = Mix_LoadWAV("Sound/bullet.wav");
	Mix_VolumeChunk(sfx, 50);
	stopRight();
	weapon = 1;
	game = &GameManager::getSingleton();
}

bool Ship::Update(float pdt){
	Solid::Update(pdt);
	move();
	worldEdge();
	soundMap();
	return false;
}

void Ship::Draw(SDL_Surface* screen){
	Solid::Draw(screen);
}

void Ship::rapidBullet(){
	bulletSpeed += 25;
	huzzelInterval -= 5;
}

void Ship::upgradeGun(){
	weapon++;
}

Vector2 Ship::getPos(){
	return pos;
}

void Ship::setWon(bool won){
	win = won;
}

void Ship::move(){
	vel *= FRICTION;

	if(win){
		vel += (Vector2(SCREEN_WIDTH, SCREEN_HEIGTH / 2) - pos).Normalize();
		animRight();
	}
	else{
		if(game->eve.KeyDown(SDLK_d)){
			vel.x += speed;
			animRight();
		}
		else
			stopRight();
		if(game->eve.KeyDown(SDLK_a))
			vel.x -= speed;
		if(game->eve.KeyDown(SDLK_w))
			vel.y -= speed;
		if(game->eve.KeyDown(SDLK_s))
			vel.y += speed;
		if((game->eve.KeyDown(SDLK_SPACE)) && (timerBullet.get_ticks() > huzzelInterval)){
			weaponSortiment();
		}
	}
}

void Ship::worldEdge(){
	if(pos.x > 175) vel.x -= 0.07f;
	if(pos.x > 100) vel.x -= 0.08f;

	if(pos.x < 0){ 
		pos.x = 0;
		vel.x = 0;
	}
	if((pos.x > SCREEN_WIDTH - (SCREEN_WIDTH / 4) - size) && !win){
		pos.x = SCREEN_WIDTH - (SCREEN_WIDTH / 4) - size;
		vel.x = 0;
	}
	if(pos.y < 80){
		pos.y = 80;
		vel.y = 0;
	}
	if(pos.y > SCREEN_HEIGTH - size){ 
		pos.y = SCREEN_HEIGTH - size;
		vel.y = 0;
	}

	if(pos.x > SCREEN_WIDTH)
		pos.x = SCREEN_WIDTH + 500;
}

void Ship::animRight(){
	float frametime;
	frametime = time.get_ticks()%100;
	if(frametime < 50)
		frame = 1;
	else 
		frame = 2;
}

void Ship::stopRight(){
	frame = 0;
}

void Ship::soundMap(){
	int soundLeft, soundRight;
	if(SCREEN_WIDTH / 2 < pos.x)
		soundLeft = (SCREEN_WIDTH / 2) - (pos.x / 2);
	else
		soundLeft = 255;

	if(SCREEN_WIDTH / 4 > pos.x)
		soundRight = pos.x / 2;
	else
		soundRight = 255;

	Mix_SetPanning(1, soundLeft, soundRight);
}

void Ship::weaponSortiment(){
	switch(weapon){
	case 1:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		break;
	case 2:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		break;
	case 3:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		break;
	case 4:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		break;
	case 5:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		break;
	case 6:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		break;
	case 7:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), vel.x + bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), vel.x + bulletSpeed, -1), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), vel.x + bulletSpeed, 1), "Stage1");
		break;
	case 8:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		break;
	case 9:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		break;
	case 10:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		break;
	case 11:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		break;
	case 12:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		break;
	case 13:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		break;
	case 14:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		break;
	case 15:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)-13), bulletSpeed, -2), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)+18), bulletSpeed, 2), "Stage1");
		break;
	case 16:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)-13), bulletSpeed, -2), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)+18), bulletSpeed, 2), "Stage1");
		break;
	case 17:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)-13), bulletSpeed, -2), "Stage1");
		game->addEntity(new RedBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)+18), bulletSpeed, 2), "Stage1");
		break;
	case 18:
		Mix_PlayChannel(1, sfx, 0);
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+3), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed), "Stage1"); 
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)-13), bulletSpeed, -1), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + size + 5, pos.y + (size / 2)+18), bulletSpeed, 1), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)-13), bulletSpeed, -2), "Stage1");
		game->addEntity(new GreenBullet(Vector2(pos.x + (size / 2) + 5, pos.y + (size / 2)+18), bulletSpeed, 2), "Stage1");
		break;
	}
	timerBullet.start();
}

