#include "Vector2.h"

#include <cmath>

Vector2::Vector2():
x(0),
y(0)
{}
Vector2::Vector2(float xy):
x(xy),
y(xy)
{}
Vector2::Vector2(float x, float y):
x(x),
y(y)
{}
Vector2::Vector2(int xy):
x((float)xy),
y((float)xy)
{}
Vector2::Vector2(int x, int y):
x((float)x),
y((float)y)
{}
Vector2::Vector2(const Vector2& vector2):
x(vector2.x),
y(vector2.y)
{}

bool Vector2::operator==(const Vector2& vector2) const{
	if(x == vector2.x && y == vector2.y)
		return true;
	else
		return false;
}
bool Vector2::operator!=(const Vector2& vector2) const{
	if(x == vector2.x && y == vector2.y)
		return false;
	else
		return true;
}
bool Vector2::operator<(const Vector2& vector2) const{
	if(Length() < vector2.Length())
		return true;
	else
		return false;
}
bool Vector2::operator>(const Vector2& vector2) const{
	if(Length() > vector2.Length())
		return true;
	else
		return false;
}
bool Vector2::operator<=(const Vector2& vector2) const{
	if(Length() <= vector2.Length())
		return true;
	else
		return false;
}
bool Vector2::operator>=(const Vector2& vector2) const{
	if(Length() >= vector2.Length())
		return true;
	else
		return false;
}

const Vector2& Vector2::operator+=(const Vector2& vector2){
	x += vector2.x;
	y += vector2.y;
	return *this;
}
const Vector2& Vector2::operator-=(const Vector2& vector2){
	x -= vector2.x;
	y -= vector2.y;
	return *this;
}
const Vector2& Vector2::operator*=(const Vector2& vector2){
	x *= vector2.x;
	y *= vector2.y;
	return *this;
}
const Vector2& Vector2::operator/=(const Vector2& vector2){
	x /= vector2.x;
	y /= vector2.y;
	return *this;
}

Vector2 Vector2::operator+(const Vector2& vector2) const{
	Vector2 temp(*this);
	temp += vector2;
	return temp;
}
Vector2 Vector2::operator-(const Vector2& vector2) const{
	Vector2 temp(*this);
	temp -= vector2;
	return temp;
}
Vector2 Vector2::operator*(const Vector2& vector2) const{
	Vector2 temp(*this);
	temp *= vector2;
	return temp;
}
Vector2 Vector2::operator/(const Vector2& vector2) const{
	Vector2 temp(*this);
	temp /= vector2;
	return temp;
}

const Vector2& Vector2::operator*=(const float scalar){
	x *= scalar;
	y *= scalar;
	return *this;
}
const Vector2& Vector2::operator/=(const float scalar){
	x /= scalar;
	y /= scalar;
	return *this;
}
Vector2 Vector2::operator*(const float scalar) const{
	Vector2 temp(*this);
	temp *= scalar;
	return temp;
}
Vector2 Vector2::operator/(const float scalar) const{
	Vector2 temp(*this);
	temp /= scalar;
	return temp;
}
const Vector2& Vector2::operator*=(const int scalar){
	x *= scalar;
	y *= scalar;
	return *this;
}
const Vector2& Vector2::operator/=(const int scalar){
	x /= scalar;
	y /= scalar;
	return *this;
}
Vector2 Vector2::operator*(const int scalar) const{
	Vector2 temp(*this);
	temp *= scalar;
	return temp;
}
Vector2 Vector2::operator/(const int scalar) const{
	Vector2 temp(*this);
	temp /= scalar;
	return temp;
}

float Vector2::Distance(const Vector2& from, const Vector2& to){
	Vector2 tempFrom = from;
	Vector2 tempTo = to;
	return (tempTo - tempFrom).Length();
}

float Vector2::Distance(const Vector2& to){
	Vector2 tempFrom = *this;
	Vector2 tempTo = to;
	return (tempTo - tempFrom).Length();
}

float Vector2::Dot(const Vector2& a, const Vector2& b){
	return (a.x * b.x) + (a.y * b.y);
}

float Vector2::Dot(const Vector2& b){
	return (x * b.x) + (y * b.y);
}

float Vector2::Length() const{
	return sqrt(Vector2::Dot(*this, *this));
}

Vector2 Vector2::Normalize() const{
	Vector2 temp;
	float l = Length();
	temp.x = x/l;
	temp.y = y/l;

	return temp;
}

Vector2 Vector2::Conjugate() const{
	Vector2 temp(*this);
	temp.x = -temp.x;
	temp.y = -temp.y;
	return temp;
}

int Vector2::Size() const{
	return (int)(x*y);
}